@echo off
rem ********************************************************************************
rem *
rem * USRVARS.BAT
rem *
rem * This file contains the user variables for controlling the ServerGuide Scripting 
rem * Toolkit.  Setting these variables allows the user to customize the 
rem * the ServerGuide Scripting Toolkit processes.
rem *
rem * This batch file is called by the autoexec.bat.
rem *
rem ********************************************************************************


REM [General_Toolkit]
    rem *********************************************************************
    rem * Defines the fully qualified path to Scripting Toolkit assembly 
    rem * directory
    rem *********************************************************************
    set TAS_PATH=%TKDRV%\%TASDIR%

    rem *********************************************************************
    rem * Defines the fully qualified path to Scripting Toolkit files
    rem *********************************************************************
    set TK_PATH=%TAS_PATH%\%TKDIR%


    rem *********************************************************************
    rem * Defines the type of deployment.
    rem * Valid values are: 
    rem *     
    rem *   1 - Deployment via a writable media - disable media during process.
    rem *       
    rem *       Boot media will be disabled during the deployment process 
    rem *       by running alboot.exe, allowing for automation of the 
    rem *       deployment process.
    rem *     
    rem *   2 - Deployment via a non-writable media - user will be prompted
    rem *     
    rem *       The boot media is write protected, user will be prompted to 
    rem *       remove the non-writable boot media.  
    rem *       (REQUIRED for bootable CDs)
    rem *     
    rem *   3 - Deployment will be via a virtual floppy.
    rem *     
    rem *       Deployment is either through a RSA-II adapter or a BladeCenter
    rem *       Management Module.  The deployment process will exit 
    rem *       automatically so that the boot media can be unmounted.
    rem *     
    rem *   4 - Deployment using Altiris(R) Deployment Solution.
    rem *     
    rem *       The Scripting Toolkit will be used in conjunction with the 
    rem *       Altiris Deployment Solution product.
    rem *     
    rem *   5 - Deployment using Microsoft(R) Automated Deployment Services.
    rem *     
    rem *       The Scripting Toolkit will be used in conjunction with the 
    rem *       Microsoft Automated Deployment Services product.
    rem *********************************************************************
    set DPLY_TYPE=4


rem [Linux_Install]
    rem *********************************************************************
    rem * Defines the fully qualified path to the OS directory
    rem *********************************************************************
    set OS_PATH=%TAS_PATH%\os\rhas21

    rem *********************************************************************
    rem * Defines the fully qualified path to the network installation kernel
    rem *********************************************************************
    set KRL_PATH=%OS_PATH%\images\pxeboot

    rem *********************************************************************
    rem * Defines the file name of the network installation kernel file.
    rem *********************************************************************
    set KRL_FILE=vmlinuz

    rem *********************************************************************
    rem * Defines the fully qualified path to the network ram disk image.
    rem *
    rem * NOTE:
    rem * The network install initrd file normally resides in the 
    rem * images\pxeboot directory in the installation tree
    rem * on the source server. Depending on the distribution,
    rem * this file may be named:
    rem * initrd.img
    rem * initrd-everything.img
    rem *********************************************************************
    set IRD_PATH=%OS_PATH%\images\pxeboot

    rem *********************************************************************
    rem * Defines the file name of the network installation ram disk image
    rem * file.
    rem *
    rem * NOTE:  Be sure to use the 8.3 naming convention, as the Scripting
    rem *        Toolkit will access this file name under DOS.
    rem *********************************************************************
    set IRD_FILE=initrd~1.img

    rem *********************************************************************
    rem * Defines the file name of the kickstart file.
    rem *********************************************************************
    set ANS_FILE=rhas21ks.cfg

    rem *********************************************************************
    rem * Defines the kickstart file location to be passed to LOADLIN.
    rem *
    rem * NOTE:  Please consult the "Starting a Kickstart Installation"
    rem *        section of the RedHat Customization Guide for further 
    rem *        information.
    rem *********************************************************************
    set ANS_URL=http://%SRV_IP%/%TASDIR%/%TKDIR%/examples/linux/redhat/%ANS_FILE%

    rem *********************************************************************
    rem * Defines the fully qualified path to the LOADLIN executable.
    rem *********************************************************************
    set LL_PATH=%OS_PATH%\dosutils

    rem *********************************************************************
    rem * Defines the network adapter to use during the deployment process
    rem *
    rem * NOTE:  Setting this variable is recommended for target machines
    rem *        with more than one network interface card (NIC).
    rem *********************************************************************
    set DPY_NIC=eth0

    rem *********************************************************************
    rem * Defines the size of the Linux RAM disk to use in kilobytes (KB)
    rem *
    rem * NOTE:  This value must be greater than or equal to the size of the
    rem *        initial ramdisk image (initrd) after it is decompressed.
    rem *********************************************************************
    set RDSK_SZ=8196


REM [Toolkit_Updates]
    rem *********************************************************************
    rem * Determine whether to perform ANY updates or not.
    rem * Valid values:
    rem *   N - No, do not perform any updates.
    rem *   Y - Yes, perform any updates.
    rem *********************************************************************
    set DO_UPDS=N

    rem *********************************************************************
    rem * Defines whether to perform system BIOS updates or not.
    rem * Valid values:
    rem *   N - No, do not perform system BIOS updates.
    rem *   Y - Yes, perform system BIOS updates.
    rem *********************************************************************
    set UPD_BIOS=N

    rem *********************************************************************
    rem * Defines whether to perform IBM ServeRAID firmware updates or not.
    rem * Valid values:
    rem *   N - No, do not perform IBM ServeRAID firmware updates.
    rem *   Y - Yes, perform IBM ServeRAID firmware updates.
    rem *********************************************************************
    set UPD_SR=N

    rem *********************************************************************
    rem * Defines the base directory for the BIOS update files to use. This 
    rem * value will be combined with UPD_PATH to define the fully qualified
    rem * path to the BIOS update files.
    rem *********************************************************************
    set UPD_BDIR=%MACHTYPE%\BIOS

    rem *********************************************************************
    rem * Defines the base directory for the ServeRAID update files to use.
    rem * This value will be combined with UPD_PATH to define the fully
    rem * qualified path to the ServeRAID firmware update files.
    rem *********************************************************************
    set UPD_SDIR=SRVRAID

    rem *********************************************************************
    rem * Defines the fully qualified path to the BIOS/firmware files
    rem * to be used for the updates.
    rem *********************************************************************
    set UPD_PATH=%TAS_PATH%\updates


REM [RAID_Configuration]
    rem *********************************************************************
    rem * Defines whether to perform ANY type of RAID configuration.
    rem * Valid values are:
    rem *   N - No, do not perform any RAID configuration.
    rem *   Y - Yes, Perform RAID configuration.
    rem *********************************************************************
    set CFG_RD=N

    rem *********************************************************************
    rem * Defines the fully qualified path to the RAID configuration files.
    rem *********************************************************************
    set RD_PATH=%TK_PATH%\examples\raid

    rem *********************************************************************
    rem * Defines the RAID configuration file name (the PRAID policies file) 
    rem * to use when configuring the RAID controllers.  
    rem * Valid values:
    rem *   "" (blank) - Configure the RAID using default values 
    rem *                (PRAID '/d' parameter).
    rem *   Filename   - Configure the RAID using a PRAID policies file.
    rem *********************************************************************
    set RD_FILE=

    rem *********************************************************************
    rem * Defines whether the installation should stop if at least one 
    rem * RAID controller could not be configured because no PRAID policy 
    rem * was available to configure the controller.   
    rem * Valid values:
    rem *   N - No, Do not stop if there was no policy to configure a RAID 
    rem *       controller.
    rem *   Y - Yes, Stop if there is no policy to configure at least one 
    rem *       RAID controller. 
    rem *********************************************************************
    set RD_ERR1=N

    rem *********************************************************************
    rem * Defines whether the installation should stop if no supported 
    rem * RAID controllers were found in the system.  
    rem * Valid values:
    rem *	N - No, Do not stop if no supported RAID controllers were found.
    rem *	Y - Yes, Stop if no supported RAID controllers were found.
    rem *********************************************************************
    set RD_ERR2=N

